@@ -1,6 +1,6 @@
 # -*- perl -*-
 # t/data/etc/http_miniswarm.pl - Used by new 500 tests
-# $Id: http_miniswarm.pl 20 2008-05-22 23:09:05Z sanko@cpan.org $
+# $Id: http_miniswarm.pl 24 2008-07-01 23:52:15Z sanko@cpan.org $
 use strict;
 use warnings;
 use Socket;
@@ -26,7 +26,11 @@ SKIP: {
         use lib q[../../../lib];
         use Net::BitTorrent;
         use Net::BitTorrent::Util qw[compact];
+        use IO::Socket qw[SOMAXCONN];
         plan tests => int($seeds + $leeches);
+
+        skip_all(sprintf(q[SOMAXCONN is too low. (SOMAXCONN == %d)], SOMAXCONN)) if SOMAXCONN < ($seeds + $leeches);
+
         my %client;
         my $test_builder = Test::More->builder;
 
